@@ -20,6 +20,8 @@ RETRY_BACKOFF_INTERVAL = 5
 
 if os.environ.get('PANOPTES_DEBUG'):
     logging.basicConfig(level=logging.DEBUG)
+else:
+    logging.basicConfig()
 
 
 class Panoptes(object):
@@ -669,7 +671,6 @@ class PanoptesObject(object):
 
             Project.where(launch_approved=True)
         """
-
         _id = kwargs.pop('id', '')
         return cls.paginated_results(*cls.http_get(_id, params=kwargs))
 
